@@ -1,10 +1,13 @@
-use chrono::{DateTime, Local, Utc, Timelike};
+use chrono::{DateTime, Local, Utc, Timelike, Duration};
 use log::Level;
 use std::time::SystemTime;
+use std::ops::{Add, Sub};
 
 /// LogAppender append logs
 /// Appender will be running on single main thread,please do_log for new thread or new an Future
 pub trait LogAppender: Send {
+    /// this method use one coroutines run this(Multiple appenders share one Appender).
+    /// so. if you want  access the network, you can launch a coroutine using go! (| | {});
     fn do_log(&self, record: &mut FastLogRecord);
 
     fn type_name(&self) -> &'static str {
@@ -16,6 +19,8 @@ pub trait LogAppender: Send {
 pub enum Command {
     CommandRecord,
     CommandExit,
+    /// Ensure that the log splitter forces splitting and saves the log
+    CommandFlush
 }
 
 #[derive(Clone, Debug)]
@@ -45,20 +50,18 @@ pub trait RecordFormat: Send + Sync {
 }
 
 pub struct FastLogFormatRecord {
-    pub hour: u32,
+    pub duration: Duration,
 }
 
 impl RecordFormat for FastLogFormatRecord {
     fn do_format(&self, arg: &mut FastLogRecord) {
         let data;
         let now: DateTime<Utc> = chrono::DateTime::from(arg.now);
-        let now = now.with_hour(now.hour() + self.hour).unwrap();
-        let now = format!("{:36}", now.to_string());
-        // let now= format!("{:?}",arg.now);
+        let now = now.add(self.duration);
         match arg.level {
             Level::Warn | Level::Error => {
                 data = format!(
-                    "{} {} {} - {}  {}\n",
+                    "{:36} {} {} - {}  {}\n",
                     &now,
                     arg.level,
                     arg.module_path,
@@ -68,7 +71,7 @@ impl RecordFormat for FastLogFormatRecord {
             }
             _ => {
                 data = format!(
-                    "{} {} {} - {}\n",
+                    "{:36} {} {} - {}\n",
                     &now, arg.level, arg.module_path, arg.args
                 );
             }
@@ -76,3 +79,14 @@ impl RecordFormat for FastLogFormatRecord {
         arg.formated = data;
     }
 }
+
+impl FastLogFormatRecord {
+    pub fn new() -> FastLogFormatRecord {
+        let utc = chrono::Utc::now().naive_utc();
+        let tz = chrono::Local::now().naive_local();
+        let d = tz.sub(utc);
+        Self {
+            duration: d
+        }
+    }
+}
